==> mobile_pos-1.1.1.tar.gz: lib/src/shared_widgets/bankbox_network_image.dart <==
import 'package:cached_network_image/cached_network_image.dart';
import 'package:flutter/material.dart';
import 'package:mobile_pos/src/helpers/global_variables.dart';
import 'package:mobile_pos/src/helpers/helper_functions.dart';
import 'package:mobile_pos/src/styles/ravenpay_textstyles.dart';
import 'package:shimmer/shimmer.dart';

class BankBoxNetworkImage extends StatelessWidget {
  const BankBoxNetworkImage(
      {Key? key,
      this.url = '',
      this.fit = BoxFit.cover,
      this.radius = 8,
      this.size,
      this.imageBgColor,
      this.applyGrayscale = false,
      this.borderRadius = 999,
      this.fallbackText,
      this.fallbackTextColor,
      this.padding,
      this.fallbackImagePadding = 0,
      this.fallBackTextSize = 16,
      this.placeHolder,
      this.errorWidget,
      this.fallBackAssetImage})
      : super(key: key);

  final String url;
  final BoxFit fit;
  final Size? size;
  final Color? imageBgColor;
  final Color? fallbackTextColor;
  final int borderRadius;
  final String? fallBackAssetImage;
  final double radius;
  final double? padding;
  final String? fallbackText;
  final double fallBackTextSize;
  final bool applyGrayscale;
  final Widget? placeHolder;
  final Widget? errorWidget;
  final double fallbackImagePadding;

  bool get isSvg => fallBackAssetImage != null
      ? (fallBackAssetImage?.endsWith('.svg') ?? false)
      : false;

  @override
  Widget build(BuildContext context) {
    return ClipRRect(
      borderRadius: BorderRadius.circular(radius),
      child: ColorFiltered(
        colorFilter: !applyGrayscale
            ? const ColorFilter.mode(
                Colors.transparent,
                BlendMode.multiply,
              )
            : const ColorFilter.mode(
                Colors.grey,
                BlendMode.saturation,
              ),
        child: CachedNetworkImage(
          height: size?.height,
          width: size?.height,
          imageUrl: url,
          fit: fit,
          errorWidget: (context, error, stackTrace) {
            return errorWidget ??
                (fallbackText == null
                    ? isSvg
                        ? pluginConfig.logo!
                        : ClipOval(
                            child: Container(
                              margin: EdgeInsets.all(fallbackImagePadding),
                              decoration: BoxDecoration(
                                  color: imageBgColor, shape: BoxShape.circle),
                              child: Padding(
                                padding: EdgeInsets.all(padding ?? 8.0),
                                child: Image.asset(
                                  fallBackAssetImage ??
                                      loadAsset("tranx_fallback_img.png"),
                                  fit: fallBackAssetImage == null
                                      ? BoxFit.contain
                                      : fit,
                                ),
                              ),
                            ),
                          )
                    : BankBoxInitialsAvatar(
                        height: 48,
                        width: 32,
                        fontSize: fallBackTextSize,
                        initials: fallbackText ?? '',
                        textColor: fallbackTextColor,
                        thisColor: pluginConfig.theme!.primaryColor,
                      ));
          },
          imageBuilder: (context, imageProvider) => Padding(
              padding: EdgeInsets.all(padding ?? 5.5),
              child: Image(image: imageProvider)),
          placeholder: (context, url) {
            return ClipRRect(
              borderRadius: BorderRadius.circular(1000),
              child: placeHolder ??
                  Shimmer.fromColors(
                    baseColor: Colors.grey.withOpacity(0.7),
                    highlightColor:
                        pluginConfig.theme!.primaryColor.withOpacity(0.7),
                    child: Container(
                      padding: const EdgeInsets.all(6),
                      height: size?.height,
                      width: size?.width,
                    ),
                  ),
            );
          },
        ),
      ),
    );
  }
}

class BankBoxInitialsAvatar extends StatelessWidget {
  const BankBoxInitialsAvatar({
    Key? key,
    this.height = 70,
    this.width = 70,
    required this.initials,
    this.thisColor,
    this.fontSize = 16,
    this.fitContent = true,
    this.textColor,
  }) : super(key: key);
  final double height;
  final double width;
  final String initials;
  final Color? thisColor;
  final double fontSize;
  final Color? textColor;
  final bool fitContent;

  @override
  Widget build(BuildContext context) {
    return Container(
      alignment: Alignment.center,
      padding: fitContent
          ? const EdgeInsets.all(8) + const EdgeInsets.only(top: 4)
          : const EdgeInsets.all(8),
      decoration: BoxDecoration(color: thisColor, shape: BoxShape.circle),
      height: height,
      width: width,
      child: fitContent
          ? FittedBox(
              child: Text(
                _getInitials(initials).toUpperCase(),
                style:
                    headling1.copyWith(fontSize: fontSize, color: Colors.white),
              ),
            )
          : Center(
              child: Text(
                _getInitials(initials).toUpperCase(),
                style: headling1.copyWith(
                  fontSize: fontSize,
                  color: Colors.white,
                ),
              ),
            ),
    );
  }

  String _getInitials(String name) {
    name = name.trimLeft()..trimRight();

    if (name.contains(' ')) {
      var tokens = name.split(' ');
      tokens.removeWhere((element) => element.isEmpty);
      if (tokens.length == 1) {
        return tokens[0].trim().characters.first;
      } else {
        return "${tokens[0].trim().characters.first}${tokens[1].trim().characters.first}";
      }
    } else {
      return name.trim().characters.first;
    }
  }
}

==> mobile_pos-2.0.0.tar.gz: lib/src/shared_widgets/bankbox_network_image.dart <==
import 'package:cached_network_image/cached_network_image.dart';
import 'package:flutter/material.dart';
import 'package:mobile_pos/src/helpers/global_variables.dart';
import 'package:mobile_pos/src/helpers/helper_functions.dart';
import 'package:mobile_pos/src/styles/ravenpay_textstyles.dart';
import 'package:shimmer/shimmer.dart';

class BankBoxNetworkImage extends StatelessWidget {
  const BankBoxNetworkImage(
      {super.key,
      this.url = '',
      this.fit = BoxFit.cover,
      this.radius = 8,
      this.size,
      this.imageBgColor,
      this.applyGrayscale = false,
      this.borderRadius = 999,
      this.fallbackText,
      this.fallbackTextColor,
      this.padding,
      this.fallbackImagePadding = 0,
      this.fallBackTextSize = 16,
      this.placeHolder,
      this.errorWidget,
      this.fallBackAssetImage});

  final String url;
  final BoxFit fit;
  final Size? size;
  final Color? imageBgColor;
  final Color? fallbackTextColor;
  final int borderRadius;
  final String? fallBackAssetImage;
  final double radius;
  final double? padding;
  final String? fallbackText;
  final double fallBackTextSize;
  final bool applyGrayscale;
  final Widget? placeHolder;
  final Widget? errorWidget;
  final double fallbackImagePadding;

  bool get isSvg => fallBackAssetImage != null
      ? (fallBackAssetImage?.endsWith('.svg') ?? false)
      : false;

  @override
  Widget build(BuildContext context) {
    return ClipRRect(
      borderRadius: BorderRadius.circular(radius),
      child: ColorFiltered(
        colorFilter: !applyGrayscale
            ? const ColorFilter.mode(
                Colors.transparent,
                BlendMode.multiply,
              )
            : const ColorFilter.mode(
                Colors.grey,
                BlendMode.saturation,
              ),
        child: CachedNetworkImage(
          height: size?.height,
          width: size?.height,
          imageUrl: url,
          fit: fit,
          errorWidget: (context, error, stackTrace) {
            return errorWidget ??
                (fallbackText == null
                    ? isSvg
                        ? pluginConfig.logo!
                        : ClipOval(
                            child: Container(
                              margin: EdgeInsets.all(fallbackImagePadding),
                              decoration: BoxDecoration(
                                  color: imageBgColor, shape: BoxShape.circle),
                              child: Padding(
                                padding: EdgeInsets.all(padding ?? 8.0),
                                child: Image.asset(
                                  fallBackAssetImage ??
                                      loadAsset("tranx_fallback_img.png"),
                                  fit: fallBackAssetImage == null
                                      ? BoxFit.contain
                                      : fit,
                                ),
                              ),
                            ),
                          )
                    : BankBoxInitialsAvatar(
                        height: 48,
                        width: 32,
                        fontSize: fallBackTextSize,
                        initials: fallbackText ?? '',
                        textColor: fallbackTextColor,
                        thisColor: pluginConfig.theme!.primaryColor,
                      ));
          },
          imageBuilder: (context, imageProvider) => Padding(
              padding: EdgeInsets.all(padding ?? 5.5),
              child: Image(image: imageProvider)),
          placeholder: (context, url) {
            return ClipRRect(
              borderRadius: BorderRadius.circular(1000),
              child: placeHolder ??
                  Shimmer.fromColors(
                    baseColor: Colors.grey.withOpacity(0.7),
                    highlightColor:
                        pluginConfig.theme!.primaryColor.withOpacity(0.7),
                    child: Container(
                      padding: const EdgeInsets.all(6),
                      height: size?.height,
                      width: size?.width,
                    ),
                  ),
            );
          },
        ),
      ),
    );
  }
}

class BankBoxInitialsAvatar extends StatelessWidget {
  const BankBoxInitialsAvatar({
    super.key,
    this.height = 70,
    this.width = 70,
    required this.initials,
    this.thisColor,
    this.fontSize = 16,
    this.fitContent = true,
    this.textColor,
  });
  final double height;
  final double width;
  final String initials;
  final Color? thisColor;
  final double fontSize;
  final Color? textColor;
  final bool fitContent;

  @override
  Widget build(BuildContext context) {
    return Container(
      alignment: Alignment.center,
      padding: fitContent
          ? const EdgeInsets.all(8) + const EdgeInsets.only(top: 4)
          : const EdgeInsets.all(8),
      decoration: BoxDecoration(color: thisColor, shape: BoxShape.circle),
      height: height,
      width: width,
      child: fitContent
          ? FittedBox(
              child: Text(
                _getInitials(initials).toUpperCase(),
                style:
                    headling1.copyWith(fontSize: fontSize, color: Colors.white),
              ),
            )
          : Center(
              child: Text(
                _getInitials(initials).toUpperCase(),
                style: headling1.copyWith(
                  fontSize: fontSize,
                  color: Colors.white,
                ),
              ),
            ),
    );
  }

  String _getInitials(String name) {
    name = name.trimLeft()..trimRight();

    if (name.contains(' ')) {
      var tokens = name.split(' ');
      tokens.removeWhere((element) => element.isEmpty);
      if (tokens.length == 1) {
        return tokens[0].trim().characters.first;
      } else {
        return "${tokens[0].trim().characters.first}${tokens[1].trim().characters.first}";
      }
    } else {
      return name.trim().characters.first;
    }
  }
}
